@@ -61,6 +61,11 @@ __PACKAGE__->add_columns
         data_type => 'boolean',
         is_nullable => 1,
     },
+    gdpr_erasable =>
+    {
+        data_type => 'boolean',
+        is_nullable => 1,
+    },
 
     audit => {
         data_type => 'boolean',
@@ -263,10 +268,18 @@ OpusVL::Preferences::Schema::Result::PrfDefault
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 DESCRIPTION
 
+This table, despite its name, actually holds the field I<definitions> for the
+preferences.
+
+Each field definition is stored against the prf_owner_types table, which maps
+the host schema's table and resultset class to an internal ID.
+
+Thus we define the fields available to a prf_owner, different per type.
+
 =head1 METHODS
 
 =head2 form_options
